summaryrefslogtreecommitdiffhomepage
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/raylib.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 4f0483f1..3494adaa 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -857,7 +857,8 @@ typedef enum {
BLEND_ADD_COLORS, // Blend textures adding colors (alternative)
BLEND_SUBTRACT_COLORS, // Blend textures subtracting colors (alternative)
BLEND_ALPHA_PREMULTIPLY, // Blend premultiplied textures considering alpha
- BLEND_CUSTOM // Blend textures using custom src/dst factors (use rlSetBlendMode())
+ BLEND_CUSTOM, // Blend textures using custom src/dst factors (use rlSetBlendMode())
+ BLEND_CUSTOM_SEPARATE // Blend textures using custom rgb/alpha separate src/dst factors (use rlSetBlendModeSeparate())
} BlendMode;
// Gesture